@@ -160,3 +160,35 @@ class UserRole(object):
     }
     # 扶摇上权限管理角色的权重顺序, 从高到低
     ROLE_WEIGHT = ['dev', 's_customer', 'j_customer', 'louceng', 'guide']
+    
+class ReturnQuantityType(object):
+    # 退货单&订单上使用的退款数量类型
+    # 部分退
+    PART = "part"
+    # 整单退
+    ENTIRE = "entire"
+    # 无退货
+    NONE = "none"
+    RETURN_QUANTITY_TYPE_CHOICES = (
+        (PART, "部分退"),
+        (ENTIRE, "整单退"),
+        (NONE, "无退货")
+    )
+
+
+class ShippingMethod(object):
+    # 普通快递
+    EXPRESS = 'express'
+    # 自提
+    SELF_SERVICE = 'self_service'
+    # 闪送
+    FLASH_DELIVERY = 'flash_delivery'
+    # 自费闪送
+    SELF_FLASH = 'self_flash'
+
+    CHOICES = (
+        (EXPRESS, "快递发货"),
+        (SELF_SERVICE, "到店自提"),
+        (FLASH_DELIVERY, "闪送"),
+        (SELF_FLASH, "自费闪送"),
+    )
