@@ -1,6 +1,11 @@
+import logging
+
 from ..core.constants import MemberLevel
 from enum import Enum, unique
 
+logger = logging.getLogger(__name__)
+
+
 DISTRIBUTE_ERROR_CODE_PREFIX = 246000
 BASE_DISTRIBUTE_API_CODE = 20103000
 
@@ -451,7 +456,7 @@ class DistributeStatus(object):
     ]
 
 
-class ShippingMethod(object):
+class __ShippingMethod(object):
     # 普通快递
     EXPRESS = 'express'
     # 自提
@@ -459,6 +464,20 @@ class ShippingMethod(object):
     # 闪送
     FLASH_DELIVERY = 'flash_delivery'
 
+    CHOICES = (
+        (EXPRESS, "快递发货"),
+        (SELF_SERVICE, "到店自提"),
+        (FLASH_DELIVERY, "闪送"),
+    )
+
+    def __getattribute__(self, name: str):
+        value = super().__getattribute__(name)
+        logger.warning("sparrow_distribute.constants.ShippingMethod 已废弃, 请使用 sparrow_order_lib.core.constants.ShippingMethod 替换")
+        return value
+
+
+ShippingMethod = __ShippingMethod()
+
 
 class DistributeEventConstKey(object):
     FROM_STATUS_LIST_KEY = "from_status_list"
